<?php

declare(strict_types=1);

namespace Dedi\SyliusDpdPickUpPlugin\Form\Extension;

use Dedi\SyliusDpdPickUpPlugin\Entity\OrderInterface;
use Sylius\Bundle\CoreBundle\Form\Type\Checkout\AddressType;
use Symfony\Component\Form\AbstractTypeExtension;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;

final class AddressTypeExtension extends AbstractTypeExtension
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        /** @var OrderInterface $order */
        $order = $builder->getData();

        if (!$order->getPudoId()) {
            return;
        }

        $builder->addEventListener(FormEvents::PRE_SET_DATA, function (FormEvent $event) {
            $event->getForm()->remove('shippingAddress');
            $event->getForm()->remove('differentBillingAddress');
            $event->getForm()->remove('differentShippingAddress');
        });

        // manually remove the shipping address data as it is set with the listener on AddressType and
        // this would cause a too many field form error
        $builder->addEventListener(FormEvents::PRE_SUBMIT, function (FormEvent $event) {
            $orderData = $event->getData();
            unset($orderData['shippingAddress']);
            $event->setData($orderData);
        });
    }

    public static function getExtendedTypes(): iterable
    {
        return [
            AddressType::class,
        ];
    }
}
