<?php

declare(strict_types=1);

namespace Dedi\SyliusDpdPickUpPlugin\Model;

/**
 * Representation of a PickUp point.
 * DPD calls it Pudo, hence the name of this class.
 */
class Pudo
{
    public string $id;
    public string $name;
    public string $address1;
    public ?string $address2;
    public ?string $address3;
    public string $localHint;
    public string $zipCode;
    public string $city;
    public string $distance;
    public float $latitude;
    public float $longitude;
    public Schedule $schedule;

    public static function fromDPDResponse(array $data): self
    {
        $pudo = new self();
        $pudo->id = $data['PUDO_ID'];
        $pudo->name = $data['NAME'];
        $pudo->address1 = $data['ADDRESS1'];
        if (!empty($data['ADDRESS2']) && is_string($data['ADDRESS2'])) {
            $pudo->address2 = $data['ADDRESS2'];
        }
        if (!empty($data['ADDRESS3']) && is_string($data['ADDRESS3'])) {
            $pudo->address3 = $data['ADDRESS3'];
        }
        if (!empty($data['LOCAL_HINT']) && is_string($data['LOCAL_HINT'])) {
            $pudo->localHint = $data['LOCAL_HINT'];
        }
        $pudo->zipCode = $data['ZIPCODE'];
        $pudo->city = $data['CITY'];
        $pudo->distance = number_format($data['DISTANCE'] / 1000, 2);
        $pudo->latitude = (float) strtr($data['LATITUDE'], ',', '.');
        $pudo->longitude = (float) strtr($data['LONGITUDE'], ',', '.');

        $pudo->schedule = Schedule::fromDPDResponse($data);

        return $pudo;
    }

    public static function fromArray($data)
    {
        $pudo = new self();
        $pudo->id = $data['id'];
        $pudo->name = $data['name'];
        $pudo->address1 = $data['address1'];
        $pudo->address2 = null;
        if (!empty($data['address2']) && is_string($data['address2'])) {
            $pudo->address2 = $data['address2'];
        }
        $pudo->address3 = null;
        if (!empty($data['address3']) && is_string($data['address3'])) {
            $pudo->address3 = $data['address3'];
        }
        $pudo->zipCode = $data['zipCode'];
        $pudo->city = $data['city'];

        return $pudo;
    }
}
